@@ -9,7 +9,7 @@ from django.db import models
 from django.forms.models import model_to_dict
 from django.utils.translation import ugettext_lazy as _
 
-import settings as app_settings
+from . import settings as app_settings
 
 
 # TODO General note: attributes in docstrings, where it was not entirely clear,
